==> Full-Month-InfiDux-ERP-100_202108.zip: inc/footer.php <==
        
        <footer class="footer text-center text-sm-left">
            &copy; Copyright <script>new Date().getFullYear()>2010&&document.write(""+new Date().getFullYear());</script> Infidux Business Solution. 
            <span class="d-none d-sm-inline-block float-right">Infidux ERP Solution by <!-- <i class="mdi mdi-heart text-danger"></i> --> <a href="https://accessystem.com" target="_blank"><img src="<?php echo @DOCUMENT_ROOT_CLASS; ?>assets/images/accessystem-logo-long.png"alt="ACCESSYSTEM® - Technologies Inc" style="height:12px; width:auto;padding-bottom:1px;padding-top:-3px;"></a></span>
        </footer><!--end footer-->
    </div>
    
    <!-- jQuery  -->
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/js/bootstrap.bundle.min.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/js/metismenu.min.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/js/waves.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/js/feather.min.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/js/simplebar.min.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/js/moment.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/daterangepicker/daterangepicker.js"></script>

        
        <!-- App js -->
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/js/app.js"></script>

        <!-- Required datatable js -->
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/datatables/jquery.dataTables.min.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/datatables/dataTables.bootstrap4.min.js"></script>
        <!-- Buttons examples -->
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/datatables/dataTables.buttons.min.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/datatables/buttons.bootstrap4.min.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/datatables/jszip.min.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/datatables/pdfmake.min.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/datatables/vfs_fonts.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/datatables/buttons.html5.min.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/datatables/buttons.print.min.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/datatables/buttons.colVis.min.js"></script>
        <!-- Responsive examples -->
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/datatables/dataTables.responsive.min.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/datatables/responsive.bootstrap4.min.js"></script>
        <script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>
        
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/treeview/jstree.min.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/pages/jquery.treeview.init.js"></script>

        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/bootstrap-colorpicker/js/bootstrap-colorpicker.min.js"></script>

        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/pages/jquery.forms-advanced.js"></script>
        
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/RWD-Table-Patterns/dist/js/rwd-table.min.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/pages/jquery.responsive-table.init.js"></script> 
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/leaflet/leaflet.js"></script> 
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/lightpick/lightpick.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/pages/jquery.profile.init.js"></script> 
        
        <script type="text/javascript" src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>
        <script src="https://code.jquery.com/ui/1.12.1/jquery-ui.js"></script>
    </body>

</html>
<script>
  $(document).ready(function () {
    $("#flash-msg").delay(7000).fadeOut("slow");
    $(".select2").select2();
  });
</script>
<!-- TopBarTime Script
    ============================================= -->
    
    <script type="text/javascript">
        tday=new Array("Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday");
        tmonth=new Array("January","February","March","April","May","June","July","August","September","October","November","December");

        function GetClock(){
            var d=new Date();
            var nday=d.getDay(),nmonth=d.getMonth(),ndate=d.getDate(),nyear=d.getFullYear();
            var nhour=d.getHours(),nmin=d.getMinutes(),nsec=d.getSeconds(),ap;

            if(nhour==0){ap=" AM";nhour=12;}
            else if(nhour<12){ap=" AM";}
            else if(nhour==12){ap=" PM";}
            else if(nhour>12){ap=" PM";nhour-=12;}

            if(nmin<=9) nmin="0"+nmin;
            if(nsec<=9) nsec="0"+nsec;

            document.getElementById('Dash_Date1').innerHTML=""+tday[nday]+",  "+tmonth[nmonth]+" "+ndate+"  -  "+nyear+",   "+nhour+":"+nmin+":"+nsec+ap+"";
        }

        window.onload=function(){
            GetClock();
            setInterval(GetClock,1000);
        }
    </script>
<style type="text/css">
.select2_con > .select2-container {
    width: 100% !important;
}
</style>
<div class="modal fade " id="modal_set_warehouse" tabindex="-1" role="dialog" aria-labelledby="myLargeModalLabel" aria-hidden="true">
    <div class="modal-dialog " role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h4 class="modal-title m-0" id="myLargeModalLabel">Select Login Warehouse</h4>
            </div><!--end modal-header-->
            <p></p>
            <div class="col-lg-12">
                <div class="card">
                    <div class="card-body">
                        <form action="" method="post" class="form-group">
                            <div class="col-md-12">
                                <label>Select Warehouse</label>
                            </div>
                            <div class="col-md-12 select2_con">
                                <?php $warehouseData = $commonFunctions->getData('invty_wrhus',' WHERE status = 0 '); ?>
                                <select class="select2 form-control" name="warehouse_id" id="fwarehouse_id" required="">
                                    <option value="">Select Warehouse</option>
                                    <?php foreach ($warehouseData as $rw) { ?>
                                        <option value="<?php echo $rw['id'];?>" <?php echo (@$editData['warehouse_id'] == $rw['id'])?"selected":"";?> ><?php echo $rw['short_name_location']; ?></option>     
                                    <?php } ?>
                                </select>
                            </div>
                        </form>
                    </div><!--end card-body--> 
                </div><!--end card--> 
            </div> <!--end col-->
        </div><!--end modal-content-->
    </div><!--end modal-dialog-->
</div><!--end modal-->
<?php if(empty($_SESSION['warehouse_id'])){ ?>
<script type="text/javascript">
    $('#modal_set_warehouse').modal({
        backdrop: 'static',
        keyboard: false
    })
    $("#modal_set_warehouse").modal("show");
    $("#fwarehouse_id").change(function(){
        var fwarehouse_id = $("#fwarehouse_id option:selected").val();
        document.cookie = "warehouse_id="+fwarehouse_id;
        <?php 
            $_SESSION['warehouse_id'] = @$_COOKIE['warehouse_id'];
        ?>

        /*$.ajax({
            type: 'POST',
            url: "",
            data: {"action":"footer_ajax_call","warehouse_id":fwarehouse_id},
            success: function(response) { 

            }
        });*/
        if("<?php echo $_SESSION['warehouse_id'];?>" != ''){
            window.location.href = "";
        }
    });
</script>
<?php } ?>

==> Full-Month-InfiDux-ERP-100_202109.zip: inc/footer.php <==
        
        <footer class="footer text-center text-sm-left">
            &copy; Copyright <script>new Date().getFullYear()>2010&&document.write(""+new Date().getFullYear());</script> Infidux Business Solution. 
            <span class="d-none d-sm-inline-block float-right">Infidux ERP Solution by <!-- <i class="mdi mdi-heart text-danger"></i> --> <a href="https://accessystem.com" target="_blank"><img src="<?php echo @DOCUMENT_ROOT_CLASS; ?>assets/images/accessystem-logo-long.png"alt="ACCESSYSTEM® - Technologies Inc" style="height:12px; width:auto;padding-bottom:1px;padding-top:-3px;"></a></span>
        </footer><!--end footer-->
    </div>
    
    <!-- jQuery  -->
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/js/bootstrap.bundle.min.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/js/metismenu.min.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/js/waves.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/js/feather.min.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/js/simplebar.min.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/js/moment.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/daterangepicker/daterangepicker.js"></script>

        
        <!-- App js -->
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/js/app.js"></script>

        <!-- Required datatable js -->
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/datatables/jquery.dataTables.min.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/datatables/dataTables.bootstrap4.min.js"></script>
        <!-- Buttons examples -->
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/datatables/dataTables.buttons.min.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/datatables/buttons.bootstrap4.min.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/datatables/jszip.min.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/datatables/pdfmake.min.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/datatables/vfs_fonts.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/datatables/buttons.html5.min.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/datatables/buttons.print.min.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/datatables/buttons.colVis.min.js"></script>
        <!-- Responsive examples -->
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/datatables/dataTables.responsive.min.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/datatables/responsive.bootstrap4.min.js"></script>
        <script src="https://cdn.jsdelivr.net/npm/select2@4.1.0-rc.0/dist/js/select2.min.js"></script>
        
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/treeview/jstree.min.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/pages/jquery.treeview.init.js"></script>

        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/bootstrap-colorpicker/js/bootstrap-colorpicker.min.js"></script>

        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/pages/jquery.forms-advanced.js"></script>
        
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/RWD-Table-Patterns/dist/js/rwd-table.min.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/pages/jquery.responsive-table.init.js"></script> 
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/leaflet/leaflet.js"></script> 
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/plugins/lightpick/lightpick.js"></script>
        <script src="<?php echo DOCUMENT_ROOT_CLASS;?>assets/pages/jquery.profile.init.js"></script> 
        
        <script type="text/javascript" src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>
        <script src="https://code.jquery.com/ui/1.12.1/jquery-ui.js"></script>
    </body>

</html>
<script>
  $(document).ready(function () {
    $("#flash-msg").delay(7000).fadeOut("slow");
    $(".select2").select2();
  });
</script>
<!-- TopBarTime Script
    ============================================= -->
    
    <script type="text/javascript">
        tday=new Array("Sunday","Monday","Tuesday","Wednesday","Thursday","Friday","Saturday");
        tmonth=new Array("January","February","March","April","May","June","July","August","September","October","November","December");

        function GetClock(){
            var d=new Date();
            var nday=d.getDay(),nmonth=d.getMonth(),ndate=d.getDate(),nyear=d.getFullYear();
            var nhour=d.getHours(),nmin=d.getMinutes(),nsec=d.getSeconds(),ap;

            if(nhour==0){ap=" AM";nhour=12;}
            else if(nhour<12){ap=" AM";}
            else if(nhour==12){ap=" PM";}
            else if(nhour>12){ap=" PM";nhour-=12;}

            if(nmin<=9) nmin="0"+nmin;
            if(nsec<=9) nsec="0"+nsec;

            document.getElementById('Dash_Date1').innerHTML=""+tday[nday]+",  "+tmonth[nmonth]+" "+ndate+"  -  "+nyear+",   "+nhour+":"+nmin+":"+nsec+ap+"";
        }

        window.onload=function(){
            GetClock();
            setInterval(GetClock,1000);
        }
    </script>
<style type="text/css">
.select2_con > .select2-container {
    width: 100% !important;
}
</style>
<div class="modal fade " id="modal_set_warehouse" tabindex="-1" role="dialog" aria-labelledby="myLargeModalLabel" aria-hidden="true">
    <div class="modal-dialog " role="document">
        <div class="modal-content">
            <div class="modal-header">
                <h4 class="modal-title m-0" id="myLargeModalLabel">Select Login Warehouse</h4>
            </div><!--end modal-header-->
            <p></p>
            <div class="col-lg-12">
                <div class="card">
                    <div class="card-body">
                        <form action="" method="post" class="form-group">
                            <div class="col-md-12">
                                <label>Select Warehouse</label>
                            </div>
                            <div class="col-md-12 select2_con">
                                <?php $warehouseData = $commonFunctions->getData('invty_wrhus',' WHERE status = 0 '); ?>
                                <select class="select2 form-control" name="warehouse_id" id="fwarehouse_id" required="">
                                    <option value="">Select Warehouse</option>
                                    <?php foreach ($warehouseData as $rw) { ?>
                                        <option value="<?php echo $rw['id'];?>" <?php echo (@$editData['warehouse_id'] == $rw['id'])?"selected":"";?> ><?php echo $rw['short_name_location']; ?></option>     
                                    <?php } ?>
                                </select>
                            </div>
                        </form>
                    </div><!--end card-body--> 
                </div><!--end card--> 
            </div> <!--end col-->
        </div><!--end modal-content-->
    </div><!--end modal-dialog-->
</div><!--end modal-->
<?php if(empty($_SESSION['warehouse_id'])){ ?>
<script type="text/javascript">
    $('#modal_set_warehouse').modal({
        backdrop: 'static',
        keyboard: false
    })
    $("#modal_set_warehouse").modal("show");
    $("#fwarehouse_id").change(function(){
        var fwarehouse_id = $("#fwarehouse_id option:selected").val();
        //document.cookie = "warehouse_id="+fwarehouse_id;
        /*<?php 
            $_SESSION['warehouse_id'] = @$_COOKIE['warehouse_id'];
        ?>*/

        $.ajax({
            type: 'POST',
            url: "<?php echo @DOCUMENT_ROOT_CLASS;?>set-session.php",
            data: {"action":"set","warehouse_id":fwarehouse_id},
            success: function(response) { 
                window.location.href = "";
            }
        });
        /*if("<?php echo $_SESSION['warehouse_id'];?>" != ''){
            window.location.href = "";
        }*/
    });
</script>
<?php } ?>
